@@ -22,7 +22,8 @@ enum {
 
 CellRegion *clipboard_copy_cell_range    (Sheet *sheet,
 					  int start_col, int start_row,
-					  int end_col,   int end_row);
+					  int end_col,   int end_row,
+					  gboolean relocate);
 
 void        clipboard_paste_region       (CellRegion *region,
 					  Sheet      *dest_sheet,
