@@ -439,7 +439,8 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 		
 		group = GNOME_CANVAS_GROUP (canvas->root);
 
-		/* determine which part of the cursor was clicked:
+		/*
+		 * determine which part of the cursor was clicked:
 		 * the border or the handlebox
 		 */
 		if (IS_LITTLE_SQUARE (item, x, y))
@@ -658,7 +659,7 @@ item_cursor_drag_event (GnomeCanvasItem *item, GdkEvent *event)
 	case GDK_BUTTON_RELEASE:
 		gnome_canvas_item_ungrab (item, event->button.time);
 		item_cursor_do_drop (item_cursor, (GdkEventButton *) event);
-		gtk_object_unref (GTK_OBJECT (item));
+		gtk_object_destroy (GTK_OBJECT (item));
 		return TRUE;
 
 	case GDK_BUTTON_PRESS:
